@@ -25,6 +25,7 @@
 #include "simulator.h"
 #include "e-node.h"
 #include "shield.h"
+#include "linkable.h"
 
 Circuit* Circuit::m_pSelf = NULL;
 
@@ -164,7 +165,7 @@ void Circuit::loadStrDoc( QString &doc )
 {
     QApplication::setOverrideCursor(Qt::WaitCursor);
 
-    QList<Component*> linkList;   // Linked  Component list
+    QList<Linkable*> linkList;   // Linked  Component list
     QList<Component*> compList;   // Pasting Component list
     QList<Connector*> conList;    // Pasting Connector list
     QList<Node*> nodeList;        // Pasting node list
@@ -218,7 +219,8 @@ void Circuit::loadStrDoc( QString &doc )
                     continue;
                 }
                 else if( prop.endsWith("/>") ) continue;
-                mComp->setPropStr( propName, prop.toString() );
+                if( propName == "MainCompId") mComp = subci->getMainComp( prop.toString() );  // If more than 1 mainComp then get Component
+                else                          mComp->setPropStr( propName, prop.toString() );
 
                 propName = "";
             }
@@ -391,8 +393,8 @@ void Circuit::loadStrDoc( QString &doc )
                     }
                     comp->setPropStr( "label", label ); //setIdLabel( label );
 
-                    QList<propGroup>* groups = comp->properties(); // Set properties in correct order
-                    for( propGroup group : *groups )
+                    QList<propGroup> groups = comp->properties(); // Set properties in correct order
+                    for( propGroup group : groups )
                     {
                         QList<ComProperty*> propList = group.propList;
                         if( propList.isEmpty() ) continue;
@@ -427,7 +429,11 @@ void Circuit::loadStrDoc( QString &doc )
                     comp->updtLabelPos();
                     comp->updtValLabelPos();
                     compList.append( comp );
-                    if( !comp->m_linkedStr.isEmpty() ) linkList.append( comp );
+                    if( comp->m_linkable )
+                    {
+                        Linkable* l = dynamic_cast<Linkable*>(comp);
+                        if( l->hasLinks() ) linkList.append( l );
+                    }
                 }
                 else qDebug() << " ERROR Creating Component: "<< type << uid;
     }   }   }
@@ -437,7 +443,8 @@ void Circuit::loadStrDoc( QString &doc )
         for( Component* comp : nodeList ) { comp->setSelected( true ); comp->move( m_deltaMove ); }
         for( Connector* con  : conList )  { con->setSelected( true );  con->move( m_deltaMove ); }
     }
-    for( Component* comp : linkList ) comp->createLinks( &compList );
+    for( Linkable* l : linkList )
+        l->createLinks( &compList );
 
     m_compList.append( compList );
     m_nodeList.append( nodeList );
@@ -644,7 +651,7 @@ void Circuit::saveBackup()
 void Circuit::saveState()
 {
     if( m_conStarted || m_circState.size() == 0 ) return;
-    m_changed = true;
+    setChanged();
 
     if( m_undo )
     {
@@ -669,6 +676,12 @@ void Circuit::saveState()
     }
 //qDebug() << "Circuit::saveState Undo:"<< m_undoStack.size()<<m_undoIndex
 //                              <<"Redo:"<<m_redoStack.size()<<m_redoIndex<<"\n";
+
+}
+
+void Circuit::setChanged()
+{
+    m_changed = true;
     QString title = MainWindow::self()->windowTitle();
     if( !title.endsWith('*') ) MainWindow::self()->setWindowTitle(title+'*');
 }
