@@ -14,6 +14,7 @@
 #include "circuit.h"
 #include "utils.h"
 #include "propdialog.h"
+#include "linkable.h"
 
 #include "doubleprop.h"
 #include "boolprop.h"
@@ -23,14 +24,13 @@
 
 int  Component::m_error = 0;
 bool Component::m_selMainCo = false;
-Component* Component::m_selecComp = NULL;
+bool Component::m_boardMode = false;
+Linkable* Component::m_selecComp = NULL;
 
 Component::Component( QObject* parent, QString type, QString id )
          : CompBase( parent, type, id )
          , QGraphicsItem()
 {
-    //setCacheMode(QGraphicsItem::DeviceCoordinateCache);
-
     m_help = "";
     m_Hflip  = 1;
     m_Vflip  = 1;
@@ -44,6 +44,8 @@ Component::Component( QObject* parent, QString type, QString id )
     m_crashed    = false;
     m_warning    = false;
     m_graphical  = false;
+    m_linkable   = false;
+    m_linked     = false;
     m_background = "";
     m_showProperty = "";
     m_linkNumber = -1;
@@ -75,8 +77,7 @@ Component::Component( QObject* parent, QString type, QString id )
     font.setPixelSize( 8 );
     m_valLabel->setFont( font );
     m_valLabel->setVisible( false );
-    
-    //setObjectName( id );
+
     if( !id.contains("-") ) id.prepend( type+"-" );
     setIdLabel( id );
 
@@ -84,34 +85,32 @@ Component::Component( QObject* parent, QString type, QString id )
     setFlag( QGraphicsItem::ItemIsSelectable, true );
 
     addPropGroup( { "CompBase", {
-new StringProp<Component>( "itemtype","","", this, &Component::itemType,  &Component::setItemType ),
-new StringProp<Component>( "CircId"  ,"","", this, &Component::getUid,    &Component::setUid ),
-new BoolProp  <Component>( "mainComp","","", this, &Component::isMainComp,&Component::setMainComp ),// Related to Subcircuit:
-new StringProp<Component>( "ShowProp","","", this, &Component::showProp,  &Component::setShowProp ),
-    }} );
-    addPropGroup( { "CompGraphic", {
+new StrProp <Component>("itemtype","","", this, &Component::itemType,  &Component::setItemType ),
+new StrProp <Component>("CircId"  ,"","", this, &Component::getUid,    &Component::setUid ),
+new BoolProp<Component>("mainComp","","", this, &Component::isMainComp,&Component::setMainComp ),// Related to Subcircuit:
+new StrProp <Component>("ShowProp","","", this, &Component::showProp,  &Component::setShowProp ),
+    }, groupHidden | groupNoCopy } );
 
-new BoolProp  <Component>( "Show_id" ,"","", this, &Component::showId,    &Component::setShowId ),
-new BoolProp<Component>  ( "Show_Val","","", this, &Component::showVal,   &Component::setShowVal ),
-//new DoubProp<Component>  ( "Value"   ,"","",this, &Component::getValue,  &Component::setValue ),
-//new StringProp<Component>( "Unit"    ,"","",this, &Component::unit,      &Component::setUnit ),
-new PointProp <Component>( "Pos"     ,"","", this, &Component::position,  &Component::setPosition ),
-new DoubProp  <Component>( "rotation","","", this, &Component::getAngle,  &Component::setAngle ),
-new IntProp   <Component>( "hflip"   ,"","", this, &Component::hflip,     &Component::setHflip ),
-new IntProp   <Component>( "vflip"   ,"","", this, &Component::vflip,     &Component::setVflip ),
-new StringProp<Component>( "label"   ,"","", this, &Component::idLabel,   &Component::setIdLabel ),
-new PointProp<Component>( "idLabPos" ,"","", this, &Component::getIdPos,  &Component::setIdPos ),
-new IntProp  <Component>( "labelrot" ,"","", this, &Component::getIdRot,  &Component::setIdRot ),
-new PointProp<Component>( "valLabPos","","", this, &Component::getValPos, &Component::setValPos ),
-new IntProp  <Component>( "valLabRot","","", this, &Component::getValRot, &Component::setValRot ),
-    }} );
+    addPropGroup( { "CompGraphic", {
+new BoolProp <Component>("Show_id"  ,"","", this, &Component::showId,    &Component::setShowId ),
+new BoolProp <Component>("Show_Val" ,"","", this, &Component::showVal,   &Component::setShowVal ),
+new PointProp<Component>("Pos"      ,"","", this, &Component::position,  &Component::setPosition ),
+new DoubProp <Component>("rotation" ,"","", this, &Component::getAngle,  &Component::setAngle ),
+new IntProp  <Component>("hflip"    ,"","", this, &Component::hflip,     &Component::setHflip ),
+new IntProp  <Component>("vflip"    ,"","", this, &Component::vflip,     &Component::setVflip ),
+new StrProp  <Component>("label"    ,"","", this, &Component::idLabel,   &Component::setIdLabel ),
+new PointProp<Component>("idLabPos" ,"","", this, &Component::getIdPos,  &Component::setIdPos ),
+new IntProp  <Component>("labelrot" ,"","", this, &Component::getIdRot,  &Component::setIdRot ),
+new PointProp<Component>("valLabPos","","", this, &Component::getValPos, &Component::setValPos ),
+new IntProp  <Component>("valLabRot","","", this, &Component::getValRot, &Component::setValRot ),
+    }, groupHidden | groupNoCopy } );
 
     addPropGroup( { "Board", {                   // Board properties
-new PointProp<Component>( "boardPos", "","", this, &Component::boardPos, &Component::setBoardPos ),
-new PointProp<Component>( "circPos" , "","", this, &Component::circPos,  &Component::setCircPos ),
-new DoubProp <Component>( "boardRot", "","", this, &Component::boardRot, &Component::setBoardRot ),
-new DoubProp <Component>( "circRot" , "","", this, &Component::circRot,  &Component::setCircRot )
-    }} );
+new PointProp<Component>("boardPos", "","", this, &Component::boardPos, &Component::setBoardPos ),
+new PointProp<Component>("circPos" , "","", this, &Component::circPos,  &Component::setCircPos ),
+new DoubProp <Component>("boardRot", "","", this, &Component::boardRot, &Component::setBoardRot ),
+new DoubProp <Component>("circRot" , "","", this, &Component::circRot,  &Component::setCircRot )
+    }, groupHidden | groupNoCopy } );
 }
 Component::~Component(){}
 
@@ -222,7 +221,10 @@ void Component::mouseMoveEvent( QGraphicsSceneMouseEvent* event )
     }
     event->accept();
     
-    QPointF delta = toGrid(event->scenePos()) - toGrid(event->lastScenePos());
+    QPointF delta(0,0);
+    if( m_boardMode ) delta = event->scenePos() - event->lastScenePos();
+    else delta = toGrid(event->scenePos()) - toGrid(event->lastScenePos());
+
     if( !(fabs( delta.x() )> 0) && !(fabs( delta.y() )> 0) ) return;
 
     QList<QGraphicsItem*> itemlist = Circuit::self()->selectedItems();
@@ -330,10 +332,10 @@ void Component::contextMenu( QGraphicsSceneContextMenuEvent* event, QMenu* menu
 {
     if( !event && m_isMainComp ) // Main Component in Subcircuit
     {
-        QAction* propertiesAction = menu->addAction( QIcon( ":/properties.svg"),tr("Properties") );
+        /*QAction* propertiesAction = menu->addAction( QIcon( ":/properties.svg"),tr("Properties") );
         connect( propertiesAction, &QAction::triggered,
                              this, &Component::slotProperties, Qt::UniqueConnection );
-        menu->addSeparator();
+        menu->addSeparator();*/
         return;
     }
     m_eventpoint = mapToScene( toGrid(event->pos()) );
@@ -620,19 +622,19 @@ void Component::paint( QPainter* p, const QStyleOptionGraphicsItem*, QWidget* )
         if( m_opCount > 0.6 ) m_opCount = 0.0;
         p->setOpacity( m_opCount+opaci );
     }
+    else if( m_selecComp && m_linkNumber >= 0 ){
+        p->setOpacity( 0.3 );
+        p->fillRect( boundingRect(), Qt::blue  );
+        p->setOpacity( 1 );
+        p->drawText( boundingRect(), Qt::AlignCenter, QString::number(m_linkNumber) );
+        p->setOpacity( 0.12 );
+    }
     else if( !m_hidden )
     {
         if( m_isMainComp ){
             p->fillRect( boundingRect(), Qt::yellow  );
             p->setOpacity( 0.5 );
         }
-        if( m_selecComp && m_linkNumber >= 0 ){
-            p->setOpacity( 0.3 );
-            p->fillRect( boundingRect(), Qt::blue  );
-            p->setOpacity( 1 );
-            p->drawText( boundingRect(), Qt::AlignCenter, QString::number(m_linkNumber) );
-            p->setOpacity( 0.12 );
-        }
     }
     //p->drawPath( shape() );
     p->setBrush( color );
