@@ -19,6 +19,7 @@ class eNode;
 class Label;
 class Connector;
 class ConnectorLine;
+class Linkable;
 
 class MAINMODULE_EXPORT Component : public CompBase, public QGraphicsItem, public Updatable
 {
@@ -124,20 +125,20 @@ class MAINMODULE_EXPORT Component : public CompBase, public QGraphicsItem, publi
 
         virtual void setflip();
 
-        virtual void compSelected( Component* comp ){ m_selecComp = NULL;}
-
         void addSignalPin( Pin* pin );
         void remSignalPin( Pin* pin );
 
         virtual void paint( QPainter* painter, const QStyleOptionGraphicsItem*, QWidget* );
 
-        virtual void createLinks( QList<Component*>* l){;}
+        // Link components
+        virtual void setLinkedValue( int v, int i=0 ){;}
+        virtual void setLinkedString( QString str, int i=0 ){;}
+        virtual void setLinked( bool l ){ m_linked = l;}
+        bool m_linkable;
         int m_linkNumber;
-        QString m_linkedStr;
- static Component* m_selecComp;
-    //signals:
-        //void moved();
-        //void flip( int h, int v );
+ static Linkable* m_selecComp;
+
+ static bool m_boardMode;
 
     public slots:
         virtual void contextMenu( QGraphicsSceneContextMenuEvent* event, QMenu* menu );
@@ -168,6 +169,7 @@ class MAINMODULE_EXPORT Component : public CompBase, public QGraphicsItem, publi
         bool m_warning;
         bool m_crashed;
         bool m_hidden;
+        bool m_linked;
 
         QPointF m_boardPos;
         QPointF m_circPos;
