@@ -39,26 +39,15 @@ Image::Image( QObject* parent, QString type, QString id )
 
     m_movie = NULL;
 
-    addPropGroup( { "Hidden", {
-new StringProp<Image>( "Image_File", tr("Image File"),"", this, &Image::background, &Image::setBackground )
-    }} );
+    addPropGroup( {"Hidden", {
+new StrProp<Image>("Image_File", tr("Image File"),"", this, &Image::background, &Image::setBackground )
+    }, groupNoCopy | groupHidden} );
 }
 Image::~Image()
 {
     if( m_movie ) delete m_movie;
 }
 
-void Image::contextMenuEvent( QGraphicsSceneContextMenuEvent* event )
-{
-    if( !acceptedMouseButtons() ) event->ignore();
-    else{
-        event->accept();
-        QMenu* menu = new QMenu();
-        contextMenu( event, menu );
-        Component::contextMenu( event, menu );
-        menu->deleteLater();
-}   }
-
 void Image::contextMenu( QGraphicsSceneContextMenuEvent* event, QMenu* menu )
 {
     QAction* loadAction = menu->addAction( QIcon(":/load.svg"),tr("Load Image") );
@@ -66,6 +55,7 @@ void Image::contextMenu( QGraphicsSceneContextMenuEvent* event, QMenu* menu )
                    this, &Image::slotLoad, Qt::UniqueConnection );
 
     menu->addSeparator();
+    Component::contextMenu( event, menu );
 }
 
 void Image::slotLoad()
@@ -128,15 +118,21 @@ QString Image::background()
 
 void Image::paint( QPainter* p, const QStyleOptionGraphicsItem* option, QWidget* widget )
 {
-    QPen pen(Qt::black, m_border, Qt::SolidLine, Qt::RoundCap, Qt::RoundJoin);
+    Component::paint( p, option, widget );
 
-    if( isSelected() ) pen.setColor( Qt::darkGray);
-
-    p->setBrush( m_color );
+    QPen pen( Qt::black, m_border, Qt::SolidLine, Qt::RoundCap, Qt::RoundJoin);
     p->setPen( pen );
     
-    if( m_border > 0 ) p->drawRect( m_area );
-    else               p->fillRect( m_area, p->brush() );
+    double opacity = p->opacity();
+    p->setOpacity( opacity*m_opac );
+    p->fillRect( m_area, m_color );
+    p->setOpacity( opacity );
 
     p->drawPixmap( m_area, m_image, m_image.rect() );
+
+    if( m_border > 0 )
+    {
+        p->setBrush( Qt::transparent );
+        p->drawRect( m_area );
+    }
 }
