@@ -36,14 +36,15 @@ LibraryItem* TextComponent::libraryItem()
 
 TextComponent::TextComponent( QObject* parent, QString type, QString id )
              : Component( parent, type, id )
+             , Linkable()
 {
     m_graphical = true;
+    m_linkable  = true;
+    m_changed   = false;
     m_opac = 1;
     m_color = QColor( 255, 255, 220 );
     m_font  = "Helvetica [Cronyx]";
 
-    /// m_linkedComp = NULL;
-
     QFont sansFont( m_font, 10 );
     #if QT_VERSION >= QT_VERSION_CHECK(5, 9, 0)
     sansFont.setWeight( QFont::Medium );
@@ -52,9 +53,9 @@ TextComponent::TextComponent( QObject* parent, QString type, QString id )
     #endif
     sansFont.setFixedPitch(true);
 
+    QColor color = Qt::darkBlue;
+    m_fontColor = color.name();
     m_text = new QGraphicsTextItem( this );
-    //m_text->setTextInteractionFlags( Qt::TextSelectableByMouse | Qt::TextSelectableByKeyboard | Qt::TextEditable);
-    //m_text->setTextInteractionFlags( Qt::TextEditorInteraction | Qt::TextBrowserInteraction );
     m_text->setTextInteractionFlags( 0 );
     m_text->setTextWidth( 90 );
     m_text->setFont( sansFont );
@@ -62,7 +63,7 @@ TextComponent::TextComponent( QObject* parent, QString type, QString id )
     m_text->setPlainText( m_textString );
     m_text->setPos( 0, 0 );
     m_text->document()->setTextWidth(-1);
-    m_text->setDefaultTextColor( Qt::darkBlue );
+    m_text->setDefaultTextColor( color );
     m_text->setCursor( Qt::OpenHandCursor );
     //m_text->installEventFilter( this );
 
@@ -74,23 +75,27 @@ TextComponent::TextComponent( QObject* parent, QString type, QString id )
     
     setFontSize( 10 );
 
+    Simulator::self()->addToUpdateList( this );
+
     connect( m_text->document(), &QTextDocument::contentsChange,
                            this, &TextComponent::updateGeometry, Qt::UniqueConnection );
 
     addPropGroup( { tr("Main"), {
-new IntProp <TextComponent>( "Margin" , tr("Margin") ,"_Pixels", this, &TextComponent::margin, &TextComponent::setMargin ),
-new IntProp <TextComponent>( "Border" , tr("Border") ,"_Pixels", this, &TextComponent::border, &TextComponent::setBorder, "uint" ),
-new DoubProp<TextComponent>( "Opacity", tr("Opacity"),""       , this, &TextComponent::opac,   &TextComponent::setOpac )
-    }} );
+new IntProp <TextComponent>("Margin" , tr("Margin") ,"_Pixels"  , this, &TextComponent::margin,  &TextComponent::setMargin ),
+new IntProp <TextComponent>("Border" , tr("Border") ,"_Pixels"  , this, &TextComponent::border,  &TextComponent::setBorder,0,"uint" ),
+new StrProp <TextComponent>("Color"  , tr("Background Color"),"", this, &TextComponent::colorStr,&TextComponent::setColorStr ),
+new DoubProp<TextComponent>("Opacity", tr("Opacity")         ,"", this, &TextComponent::opac,    &TextComponent::setOpac )
+    }, groupNoCopy} );
     addPropGroup( { tr("Text"), {
-new StringProp<TextComponent>( "Font"       , tr("Font")       ,""       , this, &TextComponent::getFont , &TextComponent::setFont ),
-new IntProp   <TextComponent>( "Font_Size"  , tr("Font Size")  ,"_Pixels", this, &TextComponent::fontSize, &TextComponent::setFontSize ),
-new BoolProp  <TextComponent>( "Fixed_Width", tr("Fixed_Width"),""       , this, &TextComponent::fixedW  , &TextComponent::setFixedW ),
-new StringProp<TextComponent>( "Text"       , tr("Text")        ,""      , this, &TextComponent::getText , &TextComponent::setText, "textEdit" )
-    }} );
+new StrProp <TextComponent>("Font"       , tr("Font")      ,""       , this, &TextComponent::getFont  , &TextComponent::setFont ),
+new IntProp <TextComponent>("Font_Size"  , tr("Font Size") ,"_Pixels", this, &TextComponent::fontSize , &TextComponent::setFontSize ),
+new StrProp <TextComponent>("Font_Color" , tr("Font Color"),""       , this, &TextComponent::fontColor, &TextComponent::setFontColor ),
+new BoolProp<TextComponent>("Fixed_Width", tr("Fixed_Width"),""      , this, &TextComponent::fixedW   , &TextComponent::setFixedW ),
+new StrProp <TextComponent>("Text"       , tr("Text")        ,""     , this, &TextComponent::getText  , &TextComponent::setText,0,"textEdit" )
+    }, groupNoCopy} );
     addPropGroup( { "Hidden", {
-new StringProp<TextComponent>( "Links", "Links","", this, &TextComponent::getLinks , &TextComponent::setLinks )
-    }} );
+new StrProp<TextComponent>( "Links", "Links","", this, &TextComponent::getLinks , &TextComponent::setLinks )
+    }, groupHidden | groupNoCopy} );
 }
 TextComponent::~TextComponent()
 {
@@ -99,14 +104,14 @@ TextComponent::~TextComponent()
 
 void TextComponent::updateStep()
 {
-    if( m_linkedComp.isEmpty() ) return;
+    if( !m_changed ) return;
+    m_changed = false;
 
     QString text = m_textString;
 
     for( int i=0; i<m_linkedComp.size(); ++i )
     {
         Component* comp = m_linkedComp.at( i );
-        comp->m_linkNumber = i;
         comp->update();
         QString data = comp->getValLabelText();
         text.replace( "$data"+QString::number(i), data );
@@ -120,8 +125,9 @@ void TextComponent::updateGeometry(int, int, int)
     
     int margin = m_margin;
     if( margin < 0 ) margin = 0;
-    if( m_hidden ) m_area = QRect( 0, 0, 0, 0 );
-    else m_area = QRect( -margin, -margin, m_text->boundingRect().width()+margin*2, m_text->boundingRect().height()+margin*2 );
+    /// if( m_hidden ) m_area = QRect( 0, 0, 0, 0 );
+    /// else
+    m_area = QRect(-margin,-margin, m_text->boundingRect().width()+margin*2, m_text->boundingRect().height()+margin*2 );
     
     Circuit::self()->update();
 }
@@ -138,6 +144,12 @@ void TextComponent::setMargin( int margin )
     updateGeometry( 0, 0, 0 );
 }
 
+void TextComponent::setColorStr( QString color )
+{
+    m_color = QColor( color);
+    update();
+}
+
 void TextComponent::setOpac( qreal op )
 {
     if     ( op > 1 ) op = 1;
@@ -146,40 +158,33 @@ void TextComponent::setOpac( qreal op )
     update();
 }
 
-QString TextComponent::getLinks()
+void TextComponent::setFont( QString font )
 {
-    QString links;
+    if( font == "" ) return;
+    m_font = font;
 
-    for( int i=0; i<m_linkedComp.size(); ++i )
-    {
-        Component* comp = m_linkedComp.at( i );
-        links.append( comp->getUid()+"," );
-    }
-    return links;
+    QFont Tfont = m_text->font();
+    Tfont.setFamily( font );
+    m_text->setFont( Tfont );
+    updateGeometry( 0, 0, 0 );
 }
 
-void TextComponent::setLinks( QString links )
+void TextComponent::setFontSize( int size )
 {
-    m_linkedStr = links;
+    if( size < 1 ) return;
+    m_fontSize = size;
+
+    QFont font = m_text->font();
+    font.setPixelSize( size );
+    m_text->setFont( font );
+    updateGeometry( 0, 0, 0 );
 }
 
-void TextComponent::createLinks( QList<Component*>* compList )
+void TextComponent::setFontColor( QString color )
 {
-    QStringList components = m_linkedStr.split(",");
-    for( QString uid : components )
-    {
-        if( uid.isEmpty() ) continue;
-
-        for( Component* comp : *compList )
-            if( comp->getUid().contains( uid ) )
-            {
-                qDebug() << "TextComponent::createLinks"<<uid;
-                m_linkedComp.append( comp );
-                break;
-            }
-    }
-    if( !m_linkedComp.isEmpty() ) Simulator::self()->addToUpdateList( this );
-    updateStep();
+    m_fontColor = color;
+    m_text->setDefaultTextColor( QColor( color) );
+    update();
 }
 
 void TextComponent::setFixedW( bool fixedW ) 
@@ -200,60 +205,28 @@ QString TextComponent::getText()
 void TextComponent::setText( QString text )
 {
     m_textString = text;
-    if( m_linkedComp.isEmpty() ) m_text->document()->setPlainText( text );
-    else updateStep();
+    m_changed = true;
+    if( !Simulator::self()->isRunning() ) updateStep();
 }
 
-void TextComponent::setFont( QString font )
+void TextComponent::createLinks( QList<Component*>* compList )
 {
-    if( font == "" ) return;
-    m_font = font;
-    
-    QFont Tfont = m_text->font();
-    Tfont.setFamily( font );
-    m_text->setFont( Tfont );
-    updateGeometry( 0, 0, 0 );
-}
-
-void TextComponent::setFontSize( int size )
-{
-    if( size < 1 ) return;
-    m_fontSize = size;
-    
-    QFont font = m_text->font();
-    font.setPixelSize( size );
-    m_text->setFont( font );
-    updateGeometry( 0, 0, 0 );
-}
-
-void TextComponent::linkComp()
-{
-    Component::m_selecComp = this;
-    QGuiApplication::setOverrideCursor( Qt::PointingHandCursor );
-    Circuit::self()->update();
+    m_changed = true;
+    Linkable::createLinks( compList );
+    if( !Simulator::self()->isRunning() ) updateStep();
 }
 
 void TextComponent::compSelected( Component* comp )
 {
-    if( comp )
-    {
-        if( m_linkedComp.contains( comp ) )
-        {
-            comp->m_linkNumber = -1;
-            m_linkedComp.removeAll( comp );
-        }
-        else m_linkedComp.append( comp );
+    m_changed = true;
+    Linkable::compSelected( comp );
+    if( !Simulator::self()->isRunning() ) updateStep();
+}
 
-        for( int i=0; i<m_linkedComp.size(); ++i )
-        {
-            Component* comp = m_linkedComp.at( i );
-            comp->m_linkNumber = i;
-        }
-    }
-    else m_selecComp = NULL;
-    updateStep();
-
-    Simulator::self()->addToUpdateList( this );
+void TextComponent::setLinkedString( QString str, int i )
+{
+    if( i == 0 ) setText( str );
+    else         setText( m_textString+str );
 }
 
 void TextComponent::contextMenuEvent( QGraphicsSceneContextMenuEvent* event )
@@ -265,7 +238,7 @@ void TextComponent::contextMenuEvent( QGraphicsSceneContextMenuEvent* event )
 
     QAction* linkCompAction = menu->addAction( QIcon(":/subcl.png"),tr("Link to Component") );
     connect( linkCompAction, &QAction::triggered,
-                       this, &TextComponent::linkComp, Qt::UniqueConnection );
+                       this, &TextComponent::slotLinkComp, Qt::UniqueConnection );
 
     menu->addSeparator();
 
@@ -280,9 +253,10 @@ void TextComponent::paint( QPainter* p, const QStyleOptionGraphicsItem* option,
     QPen pen( QColor( 0, 0, 0 ), m_border, Qt::SolidLine, Qt::RoundCap, Qt::RoundJoin);
     p->setPen( pen );
 
-    p->setOpacity( m_opac );
-    p->fillRect( m_area, p->brush() );
-    p->setOpacity( 1 );
+    double opacity = p->opacity();
+    p->setOpacity( opacity*m_opac );
+    p->fillRect( m_area, m_color );
+    p->setOpacity( opacity );
 
     if( m_border > 0 )
     {
