@@ -16,12 +16,12 @@ class MAINMODULE_EXPORT elCapacitor : public CapacitorBase
         elCapacitor( QObject* parent, QString type, QString id );
         ~elCapacitor();
 
-        static Component* construct( QObject* parent, QString type, QString id );
-        static LibraryItem* libraryItem();
+ static Component* construct( QObject* parent, QString type, QString id );
+ static LibraryItem* libraryItem();
 
         virtual void updateStep() override;
 
-        virtual void paint( QPainter* p, const QStyleOptionGraphicsItem* option, QWidget* widget );
+        virtual void paint( QPainter* p, const QStyleOptionGraphicsItem* option, QWidget* widget ) override;
 };
 
 #endif
