@@ -38,10 +38,10 @@ KeyPad::KeyPad( QObject* parent, QString type, QString id )
     setLabelPos(-8,-16, 0);
 
     addPropGroup( { tr("Main"), {
-new IntProp   <KeyPad>( "Rows"      , tr("Rows")      ,tr("_Buttons"), this, &KeyPad::rows,      &KeyPad::setRows ,"uint" ),
-new IntProp   <KeyPad>( "Cols"      , tr("Columns")   ,tr("_Buttons"), this, &KeyPad::cols,      &KeyPad::setCols ,"uint"  ),
-new StringProp<KeyPad>( "Key_Labels", tr("Key Labels"),""        , this, &KeyPad::keyLabels, &KeyPad::setKeyLabels)
-    }} );
+new IntProp<KeyPad>("Rows"      , tr("Rows")      ,tr("_Buttons"), this, &KeyPad::rows,      &KeyPad::setRows , propNoCopy,"uint" ),
+new IntProp<KeyPad>("Cols"      , tr("Columns")   ,tr("_Buttons"), this, &KeyPad::cols,      &KeyPad::setCols , propNoCopy,"uint" ),
+new StrProp<KeyPad>("Key_Labels", tr("Key Labels"),""            , this, &KeyPad::keyLabels, &KeyPad::setKeyLabels )
+    },0} );
 }
 KeyPad::~KeyPad(){}
 
