@@ -16,6 +16,7 @@
 #include "e-node.h"
 #include "utils.h"
 #include "mcu.h"
+#include "linkable.h"
 
 #include "logicsubc.h"
 #include "board.h"
@@ -47,8 +48,12 @@ Component* SubCircuit::construct( QObject* parent, QString type, QString id )
 
     if( dataFile == "" ) // Component is not in SimulIDE, search in Circuit folder
     {
-        QDir circuitDir  = QFileInfo( Circuit::self()->getFilePath() ).absoluteDir();
-        m_subcDir = circuitDir.absoluteFilePath( "data/"+name );
+        m_subcDir = ComponentSelector::self()->getFileDir( name ); // Found in folder (no xml file)
+        if( m_subcDir.isEmpty() )                                  // Try to find a "data" folder in Circuit folder
+        {
+            QDir circuitDir = QFileInfo( Circuit::self()->getFilePath() ).absoluteDir();
+            m_subcDir = circuitDir.absoluteFilePath( "data/"+name );
+        }
     }
     else{
         QDomDocument domDoc = fileToDomDoc( dataFile, "SubCircuit::construct");
@@ -128,7 +133,7 @@ Component* SubCircuit::construct( QObject* parent, QString type, QString id )
         if( dip && ls ) // If no both files exist, this prop. is not needed
         subcircuit->addPropGroup( { tr("Main"), {
         new BoolProp<SubCircuit>( "Logic_Symbol", tr("Logic Symbol"),"", subcircuit, &SubCircuit::logicSymbol, &SubCircuit::setLogicSymbol ),
-        }} );
+        },groupNoCopy} );
         Circuit::self()->m_createSubc = false;
     }
     if( m_error > 0 )
@@ -154,7 +159,7 @@ SubCircuit::SubCircuit( QObject* parent, QString type, QString id )
           : Chip( parent, type, id )
 {
     m_icColor = QColor( 20, 30, 60 );
-    m_mainComponent = NULL;
+    //m_mainComponent = NULL;
 }
 SubCircuit::~SubCircuit(){}
 
@@ -162,6 +167,9 @@ void SubCircuit::loadSubCircuit( QString fileName )
 {
     QString doc = fileToString( fileName, "SubCircuit::loadSubCircuit" );
 
+    QString oldFilePath = Circuit::self()->getFilePath();
+    Circuit::self()->setFilePath( fileName );             // Path to find subcircuits/Scripted in our data folder
+
     QStringList graphProps;
     for( propGroup pg : m_propGroups ) // Create list of "Graphical" poperties (We don't need them)
     {
@@ -174,7 +182,7 @@ void SubCircuit::loadSubCircuit( QString fileName )
     numId = numId.split("-").last();
     Circuit* circ = Circuit::self();
 
-    QList<Component*> linkList;   // Linked  Component list
+    QList<Linkable*> linkList;   // Linked  Component list
 
     QVector<QStringRef> docLines = doc.splitRef("\n");
     for( QStringRef line : docLines )
@@ -286,24 +294,33 @@ void SubCircuit::loadSubCircuit( QString fileName )
                     }
                     if( comp->isMainComp() )
                     {
-                        m_mainComponent = comp; // This component will add it's Context Menu
-                        /*if( m_getProps ) /// Does not work: Properties need to be copied
+                        m_mainComponents[newUid] = comp; // This component will add it's Context Menu and properties
+
+                        QList<propGroup> props = comp->properties();
+                        for( propGroup pg : props )
                         {
-                            QList<propGroup> props = comp->propeties();
-                            for( propGroup pg : props )
+                            if( pg.flags & groupNoCopy ) continue;
+
+                            propGroup npg;
+                            int len = label.lastIndexOf("-");
+                            npg.name = label.mid( 0, len )+" "+pg.name;
+                            npg.flags = pg.flags;
+
+                            for( ComProperty* p : pg.propList ) // Copy properties
                             {
-                                if( pg.name.startsWith("Hid") ) continue;
-                                if( pg.name.startsWith("Mai") ) continue;
-                                if( pg.name.startsWith("Comp") ) continue;
-                                if( pg.name.startsWith("Boar") ) continue;
-                                addPropGroup( pg );
+                                if( p->flags() & propNoCopy ) continue;
+                                npg.propList.append( p );
                             }
-                        }*/
-                        //qDebug() <<comp->itemType();
+                            addPropGroup( npg, false );
+                        }
                     }
                     m_compList.append( comp );
 
-                    if( !comp->m_linkedStr.isEmpty() ) linkList.append( comp );
+                    if( comp->m_linkable )
+                    {
+                        Linkable* l = dynamic_cast<Linkable*>(comp);
+                        if( l->hasLinks() ) linkList.append( l );
+                    }
 
                     if( type == "Tunnel" ) // Make Tunnel names unique for this subcircuit
                     {
@@ -314,7 +331,10 @@ void SubCircuit::loadSubCircuit( QString fileName )
                 }   }
                 else qDebug() << "SubCircuit:"<<m_name<<m_id<< "ERROR Creating Component: "<<type<<uid<<label;
     }   }   }
-    for( Component* comp : linkList ) comp->createLinks( &m_compList );
+    for( Linkable* l : linkList )
+        l->createLinks( &m_compList );
+
+    Circuit::self()->setFilePath( oldFilePath ); // Restore original filePath
 }
 
 Pin* SubCircuit::addPin( QString id, QString type, QString label, int pos, int xpos, int ypos, int angle, int length  )
@@ -425,6 +445,12 @@ void SubCircuit::setLogicSymbol( bool ls )
     }
 }
 
+Component* SubCircuit::getMainComp( QString name )
+{
+    if( name.isEmpty() ) return m_mainComponents.value( m_mainComponents.keys().first() );
+    return m_mainComponents.value(name);
+}
+
 void SubCircuit::remove()
 {
     for( Component* comp : m_compList )
@@ -436,45 +462,52 @@ void SubCircuit::remove()
     Component::remove();
 }
 
-void SubCircuit::contextMenuEvent( QGraphicsSceneContextMenuEvent* event )
+void SubCircuit::contextMenu( QGraphicsSceneContextMenuEvent* event, QMenu* menu )
 {
-    if( !acceptedMouseButtons() ) event->ignore();
-    else{
-        event->accept();
-        QMenu* menu = new QMenu();
-        Component* mainComp = m_mainComponent;
-        QString id = m_id;
+    event->accept();
 
-        if( mainComp )
-        {
-            menu->addSection( "                            " );
-            menu->addSection( mainComp->itemType()+" at "+id );
-            menu->addSection( "" );
-            mainComp->contextMenu( NULL, menu );
+    for( Component* mainComp : m_mainComponents.values() )
+    {
+        QString compType = mainComp->getUid();
+        int pos = compType.indexOf("_")+1;
+        int len = compType.lastIndexOf("-")-pos;
+        compType = compType.mid( pos, len );
 
-            menu->addSection( "                            " );
-            menu->addSection( id );
-            menu->addSection( "" );
-        }
-        Component::contextMenu( event, menu );
-        menu->deleteLater();
-}   }
+        QMenu* submenu = menu->addMenu( QIcon(":/subc.png"), compType );
+
+        mainComp->contextMenu( NULL, submenu );
+    }
+    menu->addSeparator();
+    Component::contextMenu( event, menu );
+}
 
 QString SubCircuit::toString()
 {
     QString item = CompBase::toString();
     QString end = " />\n";
-    /*if( m_subcType >= Shield )
+
+    if( !m_mainComponents.isEmpty() )
     {
-        QString cp = " circPos=\""+getPropStr( "circPos" )+"\"";
-        item.replace( end, cp+end );
-    }*/
-    if( !m_mainComponent ) return item;
+        item.remove( end );
+        item += ">";
 
-    item.remove( end );
-    item += ">";
-    item += m_mainComponent->toString().replace( "<item ", "<mainCompProps ");
-    item += "</item>\n";
+        for( QString uid : m_mainComponents.keys() )
+        {
+            Component* mainComponent = m_mainComponents.value( uid );
+            item += "\n<mainCompProps MainCompId=\""+uid+"\" ";
+            for( propGroup pg : mainComponent->properties() )
+            {
+                if( pg.flags & groupNoCopy ) continue;
 
+                for( ComProperty* prop : pg.propList )
+                {
+                    QString val = prop->toString();
+                    if( val.isEmpty() ) continue;
+                    item += prop->name() + "=\""+val+"\" ";
+            }   }
+            item += "/>\n";
+        }
+        item += "</item>\n";
+    }
     return item;
 }
