@@ -1,4 +1,4 @@
-/***************************************************************************
+﻿/***************************************************************************
  *   Copyright (C) 2022 by Santiago González                               *
  *                                                                         *
  ***( see copyright.txt file at root folder )*******************************/
@@ -16,6 +16,8 @@
 #include "console.h"
 #include "mcu.h"
 
+#include "scriptprop.h"
+
 using namespace std;
 
 ScriptCpu::ScriptCpu( eMcu* mcu )
@@ -32,12 +34,13 @@ ScriptCpu::ScriptCpu( eMcu* mcu )
     m_getCpuReg = NULL;
     m_getStrReg = NULL;
     m_command   = NULL;
+    m_setLinkedVal= NULL;
+    m_setLinkedStr= NULL;
 
     m_mcuComp = m_mcu->component();
 
     m_aEngine->RegisterObjectType("eElement" ,0, asOBJ_REF | asOBJ_NOCOUNT );
     m_aEngine->RegisterObjectType("ScriptCpu",0, asOBJ_REF | asOBJ_NOCOUNT );
-    m_aEngine->RegisterObjectType("Uart"     ,0, asOBJ_REF | asOBJ_NOCOUNT );
     //m_aEngine->RegisterObjectType("pod", sizeof(pod), asOBJ_VALUE | asOBJ_POD);
 
     m_aEngine->RegisterGlobalProperty("ScriptCpu component", this );
@@ -47,7 +50,6 @@ ScriptCpu::ScriptCpu( eMcu* mcu )
     IoPin::registerScript( m_aEngine );
     McuPort::registerScript( m_aEngine );
     McuPin::registerScript( m_aEngine );
-    //ScriptUsart::registerScript( m_aEngine );
 
     m_aEngine->RegisterObjectMethod("ScriptCpu", "void addCpuReg(string n, string t)"
                                    , asMETHODPR( ScriptCpu, addCpuReg, (string, string), void)
@@ -102,8 +104,8 @@ ScriptCpu::ScriptCpu( eMcu* mcu )
                                    , asCALL_THISCALL );
 
     m_aEngine->RegisterObjectMethod("ScriptCpu", "IoPort@ getPort(const string port)"
-                                       , asMETHODPR( ScriptCpu, getPort, (const string), IoPort*)
-                                       , asCALL_THISCALL );
+                                   , asMETHODPR( ScriptCpu, getPort, (const string), IoPort*)
+                                   , asCALL_THISCALL );
 
     m_aEngine->RegisterObjectMethod("ScriptCpu", "IoPin@ getPin(const string pin)"
                                    , asMETHODPR( ScriptCpu, getPin, (const string), IoPin*)
@@ -118,8 +120,16 @@ ScriptCpu::ScriptCpu( eMcu* mcu )
                                    , asCALL_THISCALL );
 
     m_aEngine->RegisterObjectMethod("ScriptCpu", "void INTERRUPT( uint vector )"
-                                       , asMETHODPR( ScriptCpu, INTERRUPT, (uint32_t), void)
-                                       , asCALL_THISCALL );
+                                   , asMETHODPR( ScriptCpu, INTERRUPT, (uint32_t), void)
+                                   , asCALL_THISCALL );
+
+    m_aEngine->RegisterObjectMethod("ScriptCpu", "void setLinkedValue( int index, int v, int i )"
+                                   , asMETHODPR( ScriptCpu, setLinkedValue, (int,int,int), void)
+                                   , asCALL_THISCALL );
+
+    m_aEngine->RegisterObjectMethod("ScriptCpu", "void setLinkedString( int index, string v, int i )"
+                                   , asMETHODPR( ScriptCpu, setLinkedString, (int,const string,int), void)
+                                   , asCALL_THISCALL );
 }
 ScriptCpu::~ScriptCpu() {}
 
@@ -150,12 +160,28 @@ int ScriptCpu::compileScript()
     m_getCpuReg   = m_aEngine->GetModule(0)->GetFunctionByDecl("int getCpuReg( string reg )");
     m_getStrReg   = m_aEngine->GetModule(0)->GetFunctionByDecl("string getStrReg( string reg )");
     m_command     = m_aEngine->GetModule(0)->GetFunctionByDecl("void command( string c )");
+    m_setLinkedVal= m_aEngine->GetModule(0)->GetFunctionByDecl("void setLinkedValue( int v, int i )");
+    m_setLinkedStr= m_aEngine->GetModule(0)->GetFunctionByDecl("void setLinkedString( string str, int i )");
+
+    for( ComProperty* p : m_scriptProps ) // Get properties getters and setters from script
+    {
+        QString propName = p->name();
+        QString type = p->type();
+
+        QString getter = type+" get"+propName+"()";
+        asIScriptFunction* asFunc = m_aEngine->GetModule(0)->GetFunctionByDecl( getter.toLocal8Bit().constData() );
+        m_propGetters[propName] = asFunc;
+
+        QString setter = "void set"+propName+"("+type+")";
+        asFunc = m_aEngine->GetModule(0)->GetFunctionByDecl( setter.toLocal8Bit().constData() );
+        m_propSetters[propName] = asFunc;
+    }
 
     if( m_getCpuReg || m_getStrReg )
     {
         m_mcu->createCpuTable();
     }
-    if( m_command || m_script.contains("toConsole") )
+    if( m_command || m_script.contains("toConsole") )  /// TODELETE use TextComponent
     {
         m_mcu->createCpuTable();
         m_watcher = m_mcu->getCpuTable();
@@ -171,6 +197,8 @@ int ScriptCpu::compileScript()
 
 void ScriptCpu::updateStep()
 {
+    if( !m_changed ) return;
+    m_changed = false;
     m_mcuComp->setValLabelText( m_value );
 }
 
@@ -222,6 +250,7 @@ void ScriptCpu::toConsole( string r )
 void ScriptCpu::showValue( string r )
 {
     m_value = QString::fromStdString(r);
+    m_changed = true;
 }
 
 void ScriptCpu::addCpuReg( string name, string type )
@@ -264,6 +293,80 @@ QString ScriptCpu::getStrReg( QString val )
     return QString::fromStdString( str );
 }
 
+void ScriptCpu::addProperty( QString group, QString name, QString type )
+{
+    ComProperty* p = new ScriptProp<ScriptCpu>( name, name, "", this
+                                              , &ScriptCpu::getProp, &ScriptCpu::setProp, type );
+    m_scriptProps.push_back( p );
+
+    m_mcu->component()->addProperty( group, p );
+}
+
+QString ScriptCpu::getProp( ComProperty* p )
+{
+    QString name = p->name();
+    QString type = p->type();
+
+    asIScriptFunction* asFunc = m_propGetters.value( name );
+
+    if( !asFunc ) return "";
+
+    prepare( asFunc );
+    execute();
+
+    if( m_status != asEXECUTION_FINISHED ) return "";
+
+    if( type == "string" )
+    {
+        std::string str = *(string*)m_context->GetReturnObject();
+        return QString::fromStdString( str );
+    }
+    else if( type == "int" )
+    {
+        int64_t ret = m_context->GetReturnQWord();
+        return QString::number( ret );
+    }
+    else if( type == "uint" )
+    {
+        uint64_t ret = m_context->GetReturnQWord();
+        return QString::number( ret );
+    }
+    else if( type == "double" )
+    {
+        double ret = m_context->GetReturnDouble();
+        return QString::number( ret );
+    }
+    else if( type == "bool")
+    {
+        asBYTE ret = m_context->GetReturnByte();
+        QString retStr = ret ? "true" : "false";
+        return retStr;
+    }
+    return "";
+}
+
+void ScriptCpu::setProp( ComProperty* p, QString val )
+{
+    QString name = p->name();
+    QString type = p->type();
+
+    asIScriptFunction* asFunc = m_propSetters.value( name );
+
+    if( !asFunc ) return; // Repeated in command(), create a function for this
+    prepare( asFunc );
+    if( type == "string" )
+    {
+        std::string str = val.toStdString();
+        m_context->SetArgObject( 0, &str );
+    }
+    else if( type == "int"    ) m_context->SetArgDWord(  0, val.toInt() );
+    else if( type == "uint"   ) m_context->SetArgDWord(  0, val.toUInt() );
+    else if( type == "double" ) m_context->SetArgDouble( 0, val.toDouble() );
+    else if( type == "bool"   ) m_context->SetArgByte(   0, val == "true" );
+
+    execute();
+}
+
 void ScriptCpu::addEvent( uint time ) { Simulator::self()->addEvent( time, this ); }
 void ScriptCpu::cancelEvents()        { Simulator::self()->cancelEvents( this ); }
 uint64_t ScriptCpu::circTime()        { return Simulator::self()->circTime(); }
@@ -306,3 +409,32 @@ McuPin* ScriptCpu::getMcuPin( const string pinName )
     if( !pin ) qDebug() << "Error: ScriptCpu::getMcuPin Pin"<< name << "Doesn't exist";
     return pin;
 }
+
+void ScriptCpu::setLinkedValue( int index, int v, int i ) { m_mcuComp->setLinkedVal( index, v, i ); }
+
+void ScriptCpu::setLinkedString( int index, string str, int i )
+{
+    QString s = QString::fromStdString( str );
+    m_mcuComp->setLinkedStr( index, s, i );
+}
+
+void ScriptCpu::setLinkedVal( int v, int i )
+{
+    if( !m_setLinkedVal ) return;
+
+    prepare( m_setLinkedVal);
+    m_context->SetArgDWord( 0, v );
+    m_context->SetArgDWord( 1, i );
+    execute();
+}
+
+void ScriptCpu::setLinkedStr( QString s, int i )
+{
+    if( !m_setLinkedStr ) return;
+
+    prepare( m_setLinkedStr);
+    std::string str = s.toStdString();
+    m_context->SetArgObject( 0, &str );
+    m_context->SetArgDWord( 1, i );
+    execute();
+}
