@@ -24,8 +24,8 @@ class MAINMODULE_EXPORT ScriptCpu : public ScriptModule, public McuCpu
         virtual void voltChanged() override;
         virtual void runEvent() override;
 
-        virtual void reset();
-        virtual void runStep();
+        virtual void reset() override;
+        virtual void runStep() override;
         virtual void extClock( bool clkState ) override;
         virtual void updateStep() override;
 
@@ -42,6 +42,10 @@ class MAINMODULE_EXPORT ScriptCpu : public ScriptModule, public McuCpu
         virtual int getCpuReg( QString reg ) override;
         virtual QString getStrReg( QString ) override;
 
+        void addProperty( QString group, QString name, QString type );
+        QString getProp( ComProperty* p );
+        void setProp( ComProperty* p, QString val );
+
         void addEvent( uint time );
         void cancelEvents();
         uint64_t circTime();
@@ -59,6 +63,11 @@ class MAINMODULE_EXPORT ScriptCpu : public ScriptModule, public McuCpu
         McuPort* getMcuPort( const string portName );
         McuPin*  getMcuPin( const string pinName );
 
+        void setLinkedValue( int index, int v, int i=0  );            // Called from script
+        void setLinkedString( int index, const string str, int i=0 ); // Called from script
+        void setLinkedVal( int v, int i=0 );                          // Called from C++
+        void setLinkedStr( QString s, int i );                        // Called from C++
+
         virtual void INTERRUPT( uint vector ) override;
 
     protected:
@@ -73,6 +82,14 @@ class MAINMODULE_EXPORT ScriptCpu : public ScriptModule, public McuCpu
         asIScriptFunction* m_getStrReg;
         asIScriptFunction* m_command;
 
+        asIScriptFunction* m_setLinkedVal;
+        asIScriptFunction* m_setLinkedStr;
+
+        std::vector<ComProperty*> m_scriptProps;
+        QHash<QString, QString> m_propFunctions;
+        QHash<QString, asIScriptFunction*> m_propGetters;
+        QHash<QString, asIScriptFunction*> m_propSetters;
+
         //asIScriptContext* m_extClockCtx;
 
         QString m_value;
