@@ -17,6 +17,7 @@
 #include "mcupin.h"
 #include "mcuwdt.h"
 #include "mcucreator.h"
+#include "scriptcpu.h"
 #include "circuit.h"
 #include "simulator.h"
 #include "itemlibrary.h"
@@ -29,6 +30,7 @@
 #include "mcuintosc.h"
 #include "utils.h"
 #include "watcher.h"
+#include "linkable.h"
 
 #include "stringprop.h"
 #include "doubleprop.h"
@@ -86,9 +88,12 @@ Mcu::Mcu( QObject* parent, QString type, QString id )
     m_resetPin   = NULL;
     m_portRstPin = NULL;
     m_mcuMonitor = NULL;
-    m_autoLoad   = false;
-    m_scripted   = false;
-    m_resetPol   = false;
+    m_scriptLink = NULL;
+
+    m_autoLoad = false;
+    m_scripted = false;
+    m_resetPol = false;
+    m_linkable = true;
 
     m_serialMon = -1;
 
@@ -139,19 +144,28 @@ Mcu::Mcu( QObject* parent, QString type, QString id )
             if( found ) break;
             rNode = rNode.nextSibling();
         }
-    }else // Try to find a "data" folder in Circuit folder
-    {
-        QDir circuitDir = QFileInfo( Circuit::self()->getFilePath() ).absoluteDir();
-        QString folder = "data/"+m_device+"/";
-        m_dataFile = circuitDir.absoluteFilePath( folder+m_device+".mcu" );
-        m_pkgeFile = circuitDir.absoluteFilePath( folder+m_device+".package" );
+    }else{
+        QDir mcuDir;
+        QString folder = ComponentSelector::self()->getFileDir( m_device );
+
+        if( !folder.isEmpty() ) // Found in folder (no xml file)
+        {
+            mcuDir = QDir( folder );
+        }
+        else              // Try to find a "data" folder in Circuit folder
+        {
+            mcuDir = QFileInfo( Circuit::self()->getFilePath() ).absoluteDir();
+            folder = "data/"+m_device;
+        }
+        m_dataFile = mcuDir.absoluteFilePath( folder+"/"+m_device+".mcu" );
+        m_pkgeFile = mcuDir.absoluteFilePath( folder+"/"+m_device+".package" );
 
         QFile dataFile( m_dataFile );
         QFile pkgeFile( m_pkgeFile );
         if( !dataFile.exists() || !pkgeFile.exists() )
         {
             MessageBoxNB( "Mcu::Mcu", "                               \n"+
-                      tr("xml file not found for: %1").arg( m_device ) );
+                      tr("Files not found for: %1").arg( m_device ) );
             m_error = 1;
             return;
         }
@@ -181,23 +195,26 @@ void Mcu::setup( QString type )
     if( m_deviceType == typeMCU )
     {
     addPropGroup( { tr("Main"), {
-new DoubProp  <Mcu>("Frequency", tr("Frequency"),"MHz" , this, &Mcu::extFreq, &Mcu::setExtFreq ),
-new StringProp<Mcu>("Program"  , tr("Firmware")  ,""   , this, &Mcu::program, &Mcu::setProgram ),
-new BoolProp  <Mcu>("Auto_Load", tr("Reload hex at Simulation Start"),"", this, &Mcu::autoLoad, &Mcu::setAutoLoad ),
-new BoolProp  <Mcu>("saveEepr", tr("EEPROM persitent"),"", this, &Mcu::saveEepr, &Mcu::setSaveEepr ),
-new BoolProp  <Mcu>("Logic_Symbol", tr("Logic Symbol"),"", this, &Mcu::logicSymbol, &Mcu::setLogicSymbol )
-    }} );
+new DoubProp<Mcu>("Frequency", tr("Frequency")    ,"MHz", this, &Mcu::extFreq,    &Mcu::setExtFreq ),
+new StrProp <Mcu>("Program"  , tr("Firmware")        ,"", this, &Mcu::program,    &Mcu::setProgram ),
+new BoolProp<Mcu>("Auto_Load", tr("Reload hex at \
+                                   Simulation Start"),"", this, &Mcu::autoLoad,   &Mcu::setAutoLoad ),
+new BoolProp<Mcu>("saveEepr" , tr("EEPROM persitent"),"", this, &Mcu::saveEepr,   &Mcu::setSaveEepr ),
+new BoolProp<Mcu>("Logic_Symbol", tr("Logic Symbol") ,"", this, &Mcu::logicSymbol,&Mcu::setLogicSymbol, propNoCopy )
+    }, 0} );
+
     addPropGroup( { tr("Config"), {
-new BoolProp  <Mcu>( "Rst_enabled", tr("Enable Reset Pin")   ,"", this, &Mcu::rstPinEnabled, &Mcu::enableRstPin ),
-new BoolProp  <Mcu>( "Ext_Osc"    , tr("External Oscillator"),"", this, &Mcu::extOscEnabled, &Mcu::enableExtOsc ),
-new BoolProp  <Mcu>( "Wdt_enabled", tr("Enable WatchDog")    ,"", this, &Mcu::wdtEnabled,    &Mcu::enableWdt )
-    }} );
+new BoolProp<Mcu>("Rst_enabled", tr("Enable Reset Pin")   ,"", this, &Mcu::rstPinEnabled, &Mcu::enableRstPin ),
+new BoolProp<Mcu>("Ext_Osc"    , tr("External Oscillator"),"", this, &Mcu::extOscEnabled, &Mcu::enableExtOsc ),
+new BoolProp<Mcu>("Wdt_enabled", tr("Enable WatchDog")    ,"", this, &Mcu::wdtEnabled,    &Mcu::enableWdt )
+    }, groupNoCopy} );
+
     addPropGroup( {"Hidden", {
-new StringProp<Mcu>("varList", "","", this, &Mcu::varList,   &Mcu::setVarList),
-new StringProp<Mcu>("cpuRegs", "","", this, &Mcu::cpuRegs,   &Mcu::setCpuRegs),
-new StringProp<Mcu>("eeprom" , "","", this, &Mcu::getEeprom, &Mcu::setEeprom ),
-new IntProp   <Mcu>("SerialMon","","", this, &Mcu::serialMon, &Mcu::setSerialMon )
-    }} );
+new StrProp<Mcu>("varList"  ,"","", this, &Mcu::varList,   &Mcu::setVarList),
+new StrProp<Mcu>("cpuRegs"  ,"","", this, &Mcu::cpuRegs,   &Mcu::setCpuRegs),
+new StrProp<Mcu>("eeprom"   ,"","", this, &Mcu::getEeprom, &Mcu::setEeprom ),
+new IntProp<Mcu>("SerialMon","","", this, &Mcu::serialMon, &Mcu::setSerialMon )
+    }, groupHidden } );
     }
     else //if( m_deviceType == typeMPU )
     {
@@ -205,9 +222,10 @@ new IntProp   <Mcu>("SerialMon","","", this, &Mcu::serialMon, &Mcu::setSerialMon
 addProperty(tr("Main"),new BoolProp<Mcu>( "Logic_Symbol", tr("Logic Symbol"),"", this, &Mcu::logicSymbol, &Mcu::setLogicSymbol ) );
 
     addPropGroup( {"Hidden", {
-new StringProp<Mcu>("varList", "","", this, &Mcu::varList,   &Mcu::setVarList),
-new StringProp<Mcu>("cpuRegs", "","", this, &Mcu::cpuRegs,   &Mcu::setCpuRegs),
-    }} );
+new StrProp<Mcu>("varList", "","", this, &Mcu::varList,   &Mcu::setVarList),
+new StrProp<Mcu>("cpuRegs", "","", this, &Mcu::cpuRegs,   &Mcu::setCpuRegs),
+new StrProp<Mcu>("Links"  , "","", this, &Mcu::getLinks , &Mcu::setLinks )
+    }, groupHidden } );
     }
 }
 Mcu::~Mcu()
@@ -417,6 +435,13 @@ void Mcu::contextMenu( QGraphicsSceneContextMenuEvent* event, QMenu* menu )
                        this, &Mcu::slotmain, Qt::UniqueConnection );
     }
 
+    if( m_scriptLink )
+    {
+        QAction* linkCompAction = menu->addAction( QIcon(":/subcl.png"),tr("Link to Component") );
+        connect( linkCompAction, &QAction::triggered,
+                           this, &Mcu::slotLinkComp, Qt::UniqueConnection );
+    }
+
     if( m_deviceType == typeMCU )
     {
         QAction* loadAction = menu->addAction( QIcon(":/load.svg"),tr("Load firmware") );
@@ -460,13 +485,14 @@ void Mcu::contextMenu( QGraphicsSceneContextMenuEvent* event, QMenu* menu )
     }
     menu->addSeparator();
 
-    if( !event )
+    /*if( !event )
     {
         QAction* propertiesAction = menu->addAction( QIcon( ":/properties.svg"),tr("Properties") );
         connect( propertiesAction, &QAction::triggered,
                              this, &Mcu::slotProperties, Qt::UniqueConnection );
         menu->addSeparator();
-}   }
+    }*/
+}
 
 void Mcu::slotmain()
 {
@@ -475,6 +501,11 @@ void Mcu::slotmain()
     Circuit::self()->update();
 }
 
+void Mcu::slotLinkComp()
+{
+    Linkable::startLinking();
+}
+
 void Mcu::slotOpenMcuMonitor()
 {
     if( !m_mcuMonitor )
@@ -498,9 +529,28 @@ int Mcu::serialMon()
     return -1;
 }
 
-void Mcu::setSerialMon( int s )
+void Mcu::setSerialMon( int s ) { if( s>=0 ) slotOpenTerm( s ); }
+
+void Mcu::setLinkedVal( int index, int v, int i )
 {
-    if( s>=0 ) slotOpenTerm( s );
+    if( index >= m_linkedComp.size() ) return;
+    m_linkedComp.at( index )->setLinkedValue( v, i );
+}
+
+void Mcu::setLinkedStr( int index, QString str, int i )
+{
+    if( index >= m_linkedComp.size() ) return;
+    m_linkedComp.at( index )->setLinkedString( str, i );
+}
+
+void Mcu::setLinkedValue( int v, int i )
+{
+    if( m_scriptLink ) m_scriptLink->setLinkedVal( v, i );
+}
+
+void Mcu::setLinkedString( QString str, int i )
+{
+    if( m_scriptLink ) m_scriptLink->setLinkedStr( str, i );
 }
 
 Pin* Mcu::addPin( QString id, QString type, QString label,
